"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Machine = exports.Turnos = exports.Utils = void 0;
// import { AuthMail, DataMail, EsquemaTrabajo } from "./types";
const values_1 = require("./values");
const os_1 = require("os");
const getmac_1 = __importDefault(require("getmac"));
const winston_1 = require("winston");
const moment_timezone_1 = __importDefault(require("moment-timezone"));
const nodemailer_1 = __importDefault(require("nodemailer"));
var Utils;
(function (Utils) {
    /**
     * @param dni
     * Dado un RUN sin el DV, obtiene el dígito verificador
     */
    Utils.getDV = (dni) => {
        const adni = dni;
        let M = 0, S = 1;
        for (; dni; dni = Math.floor(dni / 10)) {
            S = (S + dni % 10 * (9 - M++ % 6)) % 11;
        }
        const dv = S ? `${S - 1}` : 'K';
        return `${adni.toString().trim()}-${dv.toString().trim()}`;
    };
    Utils.logger = winston_1.createLogger({
        level: 'info',
        format: winston_1.format.combine(winston_1.format(info => {
            info.level = info.level.toUpperCase();
            return info;
        })(), winston_1.format.colorize(), winston_1.format.timestamp({
            format: 'YYYY-MM-DD HH:mm:ss'
        }), winston_1.format.printf(info => {
            return `${info.timestamp} - ${info.level}: ${info.message}`;
        })),
        transports: [new winston_1.transports.Console()]
    });
    Utils.isJSONString = (cadena) => {
        cadena = typeof cadena !== "string" ? JSON.stringify(cadena) : cadena;
        try {
            cadena = JSON.parse(cadena);
        }
        catch (e) {
            return false;
        }
        if (typeof cadena === "object" && cadena !== null) {
            return true;
        }
        return false;
    };
    Utils.stringToAccesgroup = (str) => {
        if (!str)
            return undefined;
        return str.toUpperCase()
            .replace(/[.,\/#!$%\^&\*;:{}=\-_`~() ]/g, '')
            .normalize("NFD")
            .replace(/[\u0300-\u036f]/g, "");
    };
    Utils.momento = () => {
        return moment_timezone_1.default().tz("America/Santiago");
    };
    Utils.sendMailTo = (data, auth) => __awaiter(this, void 0, void 0, function* () {
        try {
            const host = `${auth.host}`;
            const email = `${auth.user}`;
            const pass = `${auth.passwd}`;
            const port = Number(auth.port);
            const mailTransport = nodemailer_1.default.createTransport({
                host,
                port,
                auth: { user: email, pass },
                tls: { rejectUnauthorized: false }
            });
            yield mailTransport.sendMail({
                from: email,
                to: data.mail,
                replyTo: email,
                subject: `${data.subject}`,
                html: data.body
            });
        }
        catch (error) {
            Utils.logger.error(JSON.stringify(error));
        }
    });
})(Utils = exports.Utils || (exports.Utils = {}));
var Turnos;
(function (Turnos) {
    const normalizeHourMin = (h) => (Number(h) < 10) ? `0${h}` : h;
    const normalizeViewTime = (jornada) => {
        const iniFin = jornada.split('-');
        const ini = iniFin[0].split('.');
        const fin = iniFin[1].split('.');
        const hourIni = normalizeHourMin(Number(ini[0]));
        const minIni = ini.length > 1 ? normalizeHourMin(Number(ini[1])) : '00';
        const hourFin = normalizeHourMin(Number(fin[0]));
        const minFin = fin.length > 1 ? normalizeHourMin(Number(fin[1])) : '00';
        return {
            inicio: {
                timeView: `${hourIni}:${minIni}`,
                hour: Number(hourIni),
                min: Number(minIni),
            },
            fin: {
                timeView: `${hourFin}:${minFin}`,
                hour: Number(hourFin),
                min: Number(minFin)
            }
        };
    };
    /**
     * @param esquemas
     * @param utc
     * @param daySelected
     * Determina el inicio y fin de turno en horario UTC 0 y tz nacional basado en un esquema de trabajo.
     */
    Turnos.timesTurno = (esquemas, utc, daySelected) => {
        const auxDate = new Date();
        const difHoraria = utc || values_1.DEFAULT_UTC;
        let fecha = daySelected || new Date(auxDate.setHours(auxDate.getHours() - difHoraria));
        const numberOfDay = fecha.getDay();
        let turno = values_1.DEFAULT_TURN;
        for (const eachTurno of esquemas) {
            if (eachTurno.dias.map(it => it === 7 ? 0 : it).findIndex(it => it === numberOfDay) >= 0) {
                turno = `${eachTurno.horaInicio}-${eachTurno.horaFin}`;
                break;
            }
        }
        const { inicio, fin } = normalizeViewTime(turno);
        const horaInicio = Number(inicio.hour);
        const horaFin = Number(fin.hour);
        const horaActual = new Date(new Date().getTime() - difHoraria * 60 * 60 * 1000).getHours();
        if (horaInicio > horaFin && horaActual < horaFin) {
            fecha = new Date(fecha.setDate(fecha.getDate() - 1));
        }
        const miliSecondUTCIni = new Date(fecha).setHours(horaInicio + difHoraria, inicio.min, 0, 0);
        const miliSecondTZIni = new Date(fecha).setHours(horaInicio, inicio.min, 0, 0);
        if (horaInicio > horaFin) {
            // Si ha cambiado de día, fin del turno siempre será el dia siguiente
            fecha = new Date(fecha.setDate(fecha.getDate() + 1));
        }
        const miliSecondUTCFin = new Date(fecha).setHours(horaFin + difHoraria, fin.min, 0, 0);
        const miliSecondTZFin = new Date(fecha).setHours(horaFin, fin.min, 0, 0);
        const pt1 = `${inicio.timeView} (${normalizeHourMin(new Date(miliSecondTZIni).getDate())}/${normalizeHourMin(new Date(miliSecondTZIni).getMonth() + 1)})`;
        const pt2 = `${fin.timeView} (${normalizeHourMin(new Date(miliSecondTZFin).getDate())}/${normalizeHourMin(new Date(miliSecondTZFin).getMonth() + 1)})`;
        return {
            turnoIni: {
                UTCTurno: new Date(miliSecondUTCIni).toISOString(),
                TZTurno: new Date(miliSecondTZIni).toISOString(),
                timeView: inicio.timeView
            },
            turnoFin: {
                UTCTurno: new Date(miliSecondUTCFin).toISOString(),
                TZTurno: new Date(miliSecondTZFin).toISOString(),
                timeView: fin.timeView
            },
            turnoString: `${pt1} - ${pt2}`
        };
    };
    /**
     *
     * @param begFin
     * @returns
     * Determina una fecha según un numeral. Por ej, el primer sabado de abril: begFin: 1-6-4
     */
    Turnos.getNumeralDayOfMonth = (begFin) => {
        const { month, year, day, numeral } = begFin;
        if (month > 12 || month < 1)
            return 'input error';
        if (day > 7 || day < 1)
            return 'input error';
        if (numeral > 5 || numeral < 1)
            return 'input error';
        let dateFounded = [];
        let dateInit = new Date(`${year}-${month}-01`);
        while (month === dateInit.getMonth() + 1) {
            if (dateInit.getDay() === day) {
                dateFounded.push(dateInit);
            }
            dateInit = new Date(new Date(dateInit).setDate(dateInit.getDate() + 1));
        }
        return dateFounded[numeral - 1];
    };
    Turnos.getMonthsDST = (timezone) => {
        switch (timezone) {
            case 'America/Santiago':
                return { monthIniDST: 9, monthFinDST: 4 };
            default:
                return { monthIniDST: 0, monthFinDST: 0 };
        }
    };
    Turnos.getCalcMMAtTime = (historicAssignments) => {
        let MMworked = 0;
        historicAssignments.push({ info: 'HH progress', date: new Date().toISOString(), assigned: [] });
        if (historicAssignments.length) {
            for (let index = 0; index < historicAssignments.length; index++) {
                if (historicAssignments[index].assigned.length === 0 || !historicAssignments[index + 1])
                    continue;
                const minutesTranscurred = (new Date(historicAssignments[index + 1].date).getTime() - new Date(historicAssignments[index].date).getTime()) / 60000; //expressed in minutes
                MMworked += minutesTranscurred * historicAssignments[index].assigned.length;
            }
        }
        MMworked = Math.round(MMworked);
        return MMworked;
    };
})(Turnos = exports.Turnos || (exports.Turnos = {}));
var Machine;
(function (Machine) {
    Machine.totalRam = () => {
        return (Math.round(os_1.totalmem() / 1000000)).toString() + 'MB';
    };
    Machine.getCpu = () => {
        return os_1.cpus()[0].model;
    };
    Machine.getCpuSpeed = () => {
        return os_1.cpus()[0].speed / 1000 + 'GHZ';
    };
    Machine.getMacAddress = () => {
        return getmac_1.default();
    };
    Machine.getIp = () => {
        const interfaces = os_1.networkInterfaces();
        const addresses = [];
        Object.keys(interfaces).forEach((netInterface) => {
            interfaces[netInterface].forEach((interfaceObject) => {
                if (interfaceObject.family === 'IPv4' && !interfaceObject.internal) {
                    addresses.push(interfaceObject.address);
                }
            });
        });
        return (addresses[0]);
    };
})(Machine = exports.Machine || (exports.Machine = {}));
//# sourceMappingURL=main.js.map