"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Utils = void 0;
const winston_1 = require("winston");
const moment_timezone_1 = __importDefault(require("moment-timezone"));
const nodemailer_1 = __importDefault(require("nodemailer"));
var Utils;
(function (Utils) {
    /**
     * @param dni
     * Dado un RUN sin el DV, obtiene el dígito verificador
     */
    Utils.getDV = (dni) => {
        const adni = dni;
        let M = 0, S = 1;
        for (; dni; dni = Math.floor(dni / 10)) {
            S = (S + dni % 10 * (9 - M++ % 6)) % 11;
        }
        const dv = S ? `${S - 1}` : 'K';
        return `${adni.toString().trim()}-${dv.toString().trim()}`;
    };
    Utils.logger = winston_1.createLogger({
        level: 'info',
        format: winston_1.format.combine(winston_1.format(info => {
            info.level = info.level.toUpperCase();
            return info;
        })(), winston_1.format.colorize(), winston_1.format.timestamp({
            format: 'YYYY-MM-DD HH:mm:ss'
        }), winston_1.format.printf(info => {
            return `${info.timestamp} - ${info.level}: ${info.message}`;
        })),
        transports: [new winston_1.transports.Console()]
    });
    Utils.logError = (err, place) => {
        return Utils.logger.error(`at ${place}`), console.log(err);
    };
    Utils.isJSONString = (cadena) => {
        cadena = typeof cadena !== "string" ? JSON.stringify(cadena) : cadena;
        try {
            cadena = JSON.parse(cadena);
        }
        catch (e) {
            return false;
        }
        if (typeof cadena === "object" && cadena !== null) {
            return true;
        }
        return false;
    };
    Utils.stringToAccesgroup = (str) => {
        if (!str)
            return undefined;
        return str.toUpperCase()
            .replace(/[.,\/#!$%\^&\*;:{}=\-_`~() ]/g, '')
            .normalize("NFD")
            .replace(/[\u0300-\u036f]/g, "");
    };
    Utils.momento = () => {
        return moment_timezone_1.default().tz("America/Santiago");
    };
    Utils.sendMailTo = (data, auth) => __awaiter(this, void 0, void 0, function* () {
        try {
            const host = `${auth.host}`;
            const email = `${auth.user}`;
            const pass = `${auth.passwd}`;
            const port = Number(auth.port);
            const mailTransport = nodemailer_1.default.createTransport({
                host,
                port,
                auth: { user: email, pass },
                tls: { rejectUnauthorized: false }
            });
            yield mailTransport.sendMail({
                from: email,
                to: data.mail,
                replyTo: email,
                subject: `${data.subject}`,
                html: data.body
            });
        }
        catch (error) {
            Utils.logger.error(JSON.stringify(error));
        }
    });
})(Utils = exports.Utils || (exports.Utils = {}));
//# sourceMappingURL=utils.js.map